==> bugslife_1_3_03.zip: bugslife_1_3_03/WEB-INF/src/jp/gr/java_conf/bugslife/action/SerchAction.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.action;

//===========================================================================
// import
//===========================================================================
import java.io.IOException;
import java.util.Collection;
import java.util.Locale;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.commons.logging.*;
import org.apache.struts.action.*;
import org.apache.struts.util.*;
import org.apache.commons.beanutils.*;

import java.util.*;

import jp.gr.java_conf.bugslife.form.*;
import jp.gr.java_conf.bugslife.bug.*;
import jp.gr.java_conf.bugslife.user.*;
/**
 *<PRE>
 * 
 * SerchActionNX
 *
 *</PRE>
 * @version	0.0
 * @author	k 
 */
public final class SerchAction extends BaseAction 
{
//===========================================================================
// attributes
//===========================================================================
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
//===========================================================================
// methods
//===========================================================================
	/**
	 * exevute
	 *
	 * @param mapping The ActionMapping used to select this instance
	 * @param actionForm The optional ActionForm bean for this request (if any)
	 * @param request The HTTP request we are processing
	 * @param response The HTTP response we are creating
	 *
	 * @exception Exception if business logic throws an exception
	 */
	public ActionForward doAction(ActionMapping mapping,
				 ActionForm form,
				 HttpServletRequest request,
				 HttpServletResponse response)
				throws Exception {
		/*  
		 */
		HttpSession session = getSession(request);	//sessio̎擾
		UserInfo user = (UserInfo)getAttribute(session,"UserInfo");	//OC[U̎擾
		ActionForward forward = null;
		SerchForm myForm = (SerchForm)form;
		
		String action = myForm.getAction();
		//debug
		log.debug("action = " + action);
		
		//ʕ\
		if (action.equals("show")) {
			
			//G[ꗗʂo
			forward = mapping.findForward("init");
			
		//
		} else {
			
			List bugNumbers = null;			//oOԍXg
			Collection bugs = null;					//oOXg
			
			//f[^`FbN
			ActionErrors errors = myForm.validate(mapping, request);
			if (!errors.empty()) {
				saveErrors(request, errors);
				
				if (action.equals("quick")) {
					//quick̏ꍇG[ꗗʂo
					bugs = new ArrayList();
					
					forward = mapping.findForward("failure");
				} else {
					//ڍ׌̏ꍇ͌ʂɖ߂
					forward = new ActionForward(mapping.getInput());
				}
				
			} else {
				//ڍ׌
				//ΏۂƂȂoOԍXg߂
				String where = new String(myForm.getWhere());
				bugNumbers = BugFinder.findSerchBug(where, myForm.getParams());
				
				if (bugNumbers == null) {
					bugNumbers = new ArrayList();
					bugs = new ArrayList();
					myForm.setCount(0);
					session.setAttribute("bugList", bugs);
					session.setAttribute("bugNUmberList", bugNumbers);
				    forward = mapping.findForward("failure");
				} else {
				    //1̂HIT
				    if (bugNumbers.size() == 1) {
					    //̂܂܃oOڍ׉ʂɑJڂ
					    BugNumber number = (BugNumber)bugNumbers.get(0);
						//
						List buglist = (List)BugFinder.findFullBug(number.getBno());
						
						//debug
						log.debug("size = " + buglist.size());
						
						FullBug fBug = (FullBug)buglist.get(0);
						session.setAttribute("showBug", fBug);
					    forward = mapping.findForward("one");
				
				    } else {
						//oOXg߂
						bugs = BugFinder.getBugs(bugNumbers);
						//debug
//						display(bugs);
					    forward = mapping.findForward("success");
						//̏
						//JEgZbg
						myForm.setCount(bugs.size());
						session.setAttribute("bugList", bugs);
						session.setAttribute("bugNUmberList", bugNumbers);
				    }
				}
			}
		}
		// Forward control to the specified success URI
		return forward;
	}
	//debug
	private void display(Collection list) {
		
		Iterator ite = list.iterator();
		while(ite.hasNext()) {
			
			ChoiceBug bug = (ChoiceBug)ite.next();
//			Bug bug = (Bug)ite.next();
			log.debug(bug.toString());
			
		}
		
	}
}

==> bugslife_1_3_04.zip: bugslife_1_3_04/WEB-INF/src/jp/gr/java_conf/bugslife/action/SerchAction.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.action;

//===========================================================================
// import
//===========================================================================
import java.io.IOException;
import java.util.Collection;
import java.util.Locale;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.commons.logging.*;
import org.apache.struts.action.*;
import org.apache.struts.util.*;
import org.apache.commons.beanutils.*;

import java.util.*;

import jp.gr.java_conf.bugslife.form.*;
import jp.gr.java_conf.bugslife.bug.*;
import jp.gr.java_conf.bugslife.user.*;
/**
 *<PRE>
 * 
 * SerchActionNX
 *
 *</PRE>
 * @version	0.0
 * @author	k 
 */
public final class SerchAction extends BaseAction 
{
//===========================================================================
// attributes
//===========================================================================
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
//===========================================================================
// methods
//===========================================================================
	/**
	 * exevute
	 *
	 * @param mapping The ActionMapping used to select this instance
	 * @param actionForm The optional ActionForm bean for this request (if any)
	 * @param request The HTTP request we are processing
	 * @param response The HTTP response we are creating
	 *
	 * @exception Exception if business logic throws an exception
	 */
	public ActionForward doAction(ActionMapping mapping,
				 ActionForm form,
				 HttpServletRequest request,
				 HttpServletResponse response)
				throws Exception {
		/*  
		 */
		HttpSession session = getSession(request);	//sessio̎擾
		UserInfo user = (UserInfo)getAttribute(session,"UserInfo");	//OC[U̎擾
		ActionForward forward = null;
		SerchForm myForm = (SerchForm)form;
		
		String action = myForm.getAction();
		//debug
		log.debug("action = " + action);
		
		//ʕ\
		if (action.equals("show")) {
			
			//G[ꗗʂo
			forward = mapping.findForward("init");
			
		//
		} else {
			
			List bugNumbers = null;					//oOԍXg
			Collection bugs = new ArrayList();		//oOXg
			session.setAttribute("bugList", bugs);	//G[̂߂ɂŋ̃XguĂ
			session.setAttribute("bugNUmberList", bugNumbers);
			
			//f[^`FbN
			ActionErrors errors = myForm.validate(mapping, request);
			if (!errors.empty()) {
				saveErrors(request, errors);
				
				if (action.equals("quick")) {
					//quick̏ꍇG[ꗗʂo
					bugs = new ArrayList();
					
					forward = mapping.findForward("failure");
				} else {
					//ڍ׌̏ꍇ͌ʂɖ߂
					forward = new ActionForward(mapping.getInput());
				}
				
			} else {
				//ڍ׌
				//ΏۂƂȂoOԍXg߂
				String where = new String(myForm.getWhere());
				bugNumbers = BugFinder.findSerchBug(where, myForm.getParams());
				
				if (bugNumbers == null) {
					bugNumbers = new ArrayList();
					bugs = new ArrayList();
					myForm.setCount(0);
					session.setAttribute("bugList", bugs);
					session.setAttribute("bugNUmberList", bugNumbers);
				    forward = mapping.findForward("failure");
				} else {
				    //1̂HIT
				    if (bugNumbers.size() == 1) {
					    //̂܂܃oOڍ׉ʂɑJڂ
					    BugNumber number = (BugNumber)bugNumbers.get(0);
						//
						List buglist = (List)BugFinder.findFullBug(number.getBno());
						
						//debug
						log.debug("size = " + buglist.size());
						
						FullBug fBug = (FullBug)buglist.get(0);
						session.setAttribute("showBug", fBug);
					    forward = mapping.findForward("one");
				
				    } else {
						//oOXg߂
						bugs = BugFinder.getBugs(bugNumbers);
						//debug
//						display(bugs);
					    forward = mapping.findForward("success");
						//̏
						//JEgZbg
						myForm.setCount(bugs.size());
						session.setAttribute("bugList", bugs);
						session.setAttribute("bugNUmberList", bugNumbers);
				    }
				}
			}
		}
		// Forward control to the specified success URI
		return forward;
	}
	//debug
	private void display(Collection list) {
		
		Iterator ite = list.iterator();
		while(ite.hasNext()) {
			
			ChoiceBug bug = (ChoiceBug)ite.next();
//			Bug bug = (Bug)ite.next();
			log.debug(bug.toString());
			
		}
		
	}
}
